#ifndef INCLUDE_SYSTEMS_H
#define INCLUDE_SYSTEMS_H
/* ----------------------------------------------------------------------------
 * systems.h
 * definitions for different laptop models.
 *
 * Copyright 2002 Matthias Grimm
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version
 * 2 of the License, or (at your option) any later version.
 * ----------------------------------------------------------------------------*/

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef SYS_POWERBOOK
#  define WITH_MODULE_PMAC
#  define WITH_BACKLIGHT_PMU
#endif

#ifdef SYS_MACBOOK
#  define WITH_MODULE_ACPI
#  define WITH_MODULE_IMAC
#  define WITH_BACKLIGHT_PCI
#endif

#ifdef SYS_I386_ACPI
#endif

#ifdef SYS_I386_GENERIC
#endif

#endif    /* INCLUDE_SYSTEMS_H */
